==> qmmp-plugin-pack_1.3.1.orig.tar.xz: src/Input/ffap/translations/ffap_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>Plugin FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Fichiers audio Monkey</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>About FFap Audio Plugin</source>
        <translation>A propos du plugin audio FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="158"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Plugin audio FFap Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="159"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Ce plugin fournit le support des fichiers audio Monkey (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="160"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="161"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basé sur le code de deadbeef, FFmpeg et rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="67"/>
        <source>Samples</source>
        <translation>Samples</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="68"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack_1.6.1.orig.tar.xz: src/Input/ffap/translations/ffap_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>Greffon FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Fichiers audio Monkey</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>A propos du greffon audio FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Greffon audio FFap Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Ce greffon fournit le support des fichiers audio Monkey (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basé sur le code de deadbeef, FFmpeg et rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="65"/>
        <source>Samples</source>
        <translation>Samples</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="66"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>
